package sk.novotnyr.eydee;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.File;

import javax.swing.BorderFactory;
import javax.swing.JButton;
import javax.swing.JFileChooser;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JList;
import javax.swing.JPanel;
import javax.swing.JTable;
import javax.swing.WindowConstants;
import javax.swing.event.ListSelectionEvent;
import javax.swing.event.ListSelectionListener;

public class MainForm extends JFrame implements ActionListener, ListSelectionListener {
	private ID3Reader id3Reader = new ID3Reader();
	
	private JLabel lblDirectory;
	
	private JButton btnLoad;
	
	private JList lstFiles;
	
	private JPanel id3Panel;

	private JLabel lblArtist;

	private JLabel lblTitle;

	private JButton btnShowTable;
	
	private File selectedFile;

	public MainForm() {
		initComponents();
	}

	private void initComponents() {
		setLayout(null);
		setBounds(0, 0, 450, 480);
		setDefaultCloseOperation(WindowConstants.EXIT_ON_CLOSE);
		
		lblDirectory = new JLabel("Click 'Open' to load a directory.");
		lblDirectory.setBounds(5, 5, 400, 20);
		getContentPane().add(lblDirectory);
		
		btnLoad = new JButton("Open");
		btnLoad.setBounds(5, 25, 400, 20);
		btnLoad.addActionListener(this);
		getContentPane().add(btnLoad);
		
		lstFiles = new JList();
		lstFiles.setBounds(5, 50, 400, 200);
		lstFiles.addListSelectionListener(this);
		getContentPane().add(lstFiles);
		
		// novy panel, vypneme layout manager rozhadzujuci komponenty
		id3Panel = new JPanel(null);
		id3Panel.setBounds(5, 255, 400, 50);
		id3Panel.setBorder(BorderFactory.createEtchedBorder());
		getContentPane().add(id3Panel);
		
		lblArtist = new JLabel("-iadny autor-");
		lblArtist.setBounds(5, 5, 150, 20);
		id3Panel.add(lblArtist);
		
		lblTitle = new JLabel("-iadny nzov-");
		lblTitle.setBounds(5, 25, 150, 20);
		id3Panel.add(lblTitle);		
		
		btnShowTable = new JButton("Tabuka");
		btnShowTable.setBounds(5, 320, 400, 20);
		btnShowTable.addActionListener(this);
		getContentPane().add(btnShowTable);
	}

	
	@Override
	public void actionPerformed(ActionEvent e) {
		if(e.getSource() == btnLoad) {
			btnLoadActionPerformed(e);
			return;
		}
		if(e.getSource() == btnShowTable) {
			btnShowTableActionPerformed(e);
			return;
		}
	}

	private void btnShowTableActionPerformed(ActionEvent e) {
		DirectoryForm form = new DirectoryForm(this, selectedFile);
		form.setVisible(true);
	}

	private void btnLoadActionPerformed(ActionEvent e) {
		JFileChooser fileChooser = new JFileChooser();
		fileChooser.setFileSelectionMode(JFileChooser.DIRECTORIES_ONLY);
		int dialogResult = fileChooser.showOpenDialog(this);
		if(dialogResult == JFileChooser.APPROVE_OPTION) {
			selectedFile = fileChooser.getSelectedFile();
			loadDirectory(selectedFile);
		}
	}
	
	private void lstFilesValueChanged(ListSelectionEvent e) {
		try {
			File selectedFile = (File) lstFiles.getSelectedValue();
			Tag tag = id3Reader.read(selectedFile);
			
			lblArtist.setText(tag.getTitle());
			lblTitle.setText(tag.getArtist());
		} catch (Exception ex) {
			ex.printStackTrace();
		} 
	}
	
	
	@Override
	public void valueChanged(ListSelectionEvent e) {
		lstFilesValueChanged(e);
	}
	


	private void loadDirectory(File selectedFile) {
		File[] subFiles = selectedFile.listFiles();
		lstFiles.setListData(subFiles);
	}

	public static void main(String[] args) {
		MainForm form = new MainForm();
		form.setVisible(true);
		
	}	
}
